colour.models.dataset.best_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.best_rgb Module

## Best RGB Colourspace

Defines the Best RGB colourspace:

- `BEST_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.hutchcolor.com/profiles/BestRGB.zip (Last accessed 11 April 2014)

`colour.models.dataset.best_rgb.` `BEST_RGB_PRIMARIES` = array([[ 0.73519164, 0.26480836], [ 0.21533613, 0.77415966], [ 0.13012295, 0.03483607]])

  Best RGB colourspace primaries.

  BEST_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.best_rgb.` `BEST_RGB_WHITEPOINT` = (0.34567, 0.3585)

  Best RGB colourspace whitepoint.

  BEST_RGB_WHITEPOINT : tuple

`colour.models.dataset.best_rgb.` `BEST_RGB_TO_XYZ_MATRIX` = array([[ 6.31788060e-01, 2.05397617e-01, 1.27026318e-01], [ 2.27563472e-01, 7.38429483e-01, 3.40070457e-02], [ -4.77035928e-17, 1.00193960e-02, 8.15168889e-01]])

  Best RGB colourspace to CIE XYZ colourspace matrix.

  BEST_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.best_rgb.` `XYZ_TO_BEST_RGB_MATRIX` = array([[ 1.7576676 , -0.48546193, -0.25364182], [-0.54197115, 1.50468307, 0.02168235], [ 0.00666147, -0.01849435, 1.22647315]])

  CIE XYZ colourspace to Best RGB colourspace matrix.

  XYZ_TO_BEST_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.best_rgb.` `BEST_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Best RGB colourspace.

  BEST_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.best_rgb.` `BEST_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Best RGB colourspace to linear.

  BEST_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.best_rgb.` `BEST_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1d050>

  Best RGB colourspace.

  BEST_RGB_COLOURSPACE : RGB_Colourspace